@@ -24,7 +24,7 @@ chk_date <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must be a date (non-missing Date scalar)")
+  abort_chk(x_name, " must be a date (non-missing Date scalar)", x = x)
 }
 
 #' @describeIn chk_date Validate Date
