@@ -24,7 +24,7 @@ chk_datetime <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must be a datetime (non-missing POSIXct scalar)")
+  abort_chk(x_name, " must be a datetime (non-missing POSIXct scalar)", x = x)
 }
 
 #' @describeIn chk_datetime Validate DateTime
