@@ -29,8 +29,7 @@ chk_ext <- function(x, ext, x_name = NULL) {
   chk_string(x, x_name = x_name)
   abort_chk(
     x_name, " must have extension ", cc(ext, " or "), " (not '",
-    tools::file_ext(x), "')"
-  )
+    tools::file_ext(x), "')", x = x, ext = ext)
 }
 
 #' @describeIn chk_ext Validate File Extension
