@@ -24,7 +24,7 @@ chk_false <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must be FALSE")
+  abort_chk(x_name, " must be FALSE", x = x)
 }
 
 #' @describeIn chk_false Validate FALSE
