@@ -25,9 +25,9 @@ chk_file <- function(x, x_name = NULL) {
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   chk_string(x, x_name = x_name)
   if (dir.exists(x)) {
-    abort_chk(x_name, " must specify a file ('", x, "' is a directory)")
+    abort_chk(x_name, " must specify a file ('", x, "' is a directory)", x = x)
   }
-  abort_chk(x_name, " must specify an existing file ('", x, "' can't be found)")
+  abort_chk(x_name, " must specify an existing file ('", x, "' can't be found)", x = x)
 }
 
 #' @describeIn chk_file Validate File Exists
