@@ -28,7 +28,7 @@ chk_flag <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must be a flag (TRUE or FALSE)")
+  abort_chk(x_name, " must be a flag (TRUE or FALSE)", x = x)
 }
 
 #' @describeIn chk_flag Validate Flag
