@@ -24,7 +24,7 @@ chk_list <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must be a list")
+  abort_chk(x_name, " must be a list", x = x)
 }
 
 #' @describeIn chk_list Validate List
