@@ -24,7 +24,7 @@ chk_named <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
-  abort_chk(x_name, " must be named")
+  abort_chk(x_name, " must be named", x = x)
 }
 
 #' @describeIn chk_named Validate Named
