@@ -28,7 +28,7 @@ chk_not_any_na <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
-  abort_chk(x_name, " must not have any missing values")
+  abort_chk(x_name, " must not have any missing values", x = x)
 }
 
 
