@@ -28,7 +28,7 @@ chk_not_empty <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk((substitute(x)))
-  abort_chk(x_name, " must not be empty (zero length)")
+  abort_chk(x_name, " must not be empty (zero length)", x = x)
 }
 
 #' @describeIn chk_not_empty Validate Not Empty
