@@ -24,7 +24,7 @@ chk_not_null <- function(x, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must not be NULL")
+  abort_chk(x_name, " must not be NULL", x = x)
 }
 
 #' @describeIn chk_not_null Validate Not NULL
