@@ -24,7 +24,7 @@ chk_s3_class <- function(x, class, x_name = NULL) {
     return(invisible())
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
-  abort_chk(x_name, " must inherit from S3 class '", class, "'")
+  abort_chk(x_name, " must inherit from S3 class '", class, "'", x = x, class = class)
 }
 
 #' @describeIn chk_s3_class Validate Inherits from S3 Class
